==> gbsite-1.1.1.tar.gz: gbsite/templates/gb/gb_navpage.php <==
<!--- ***
FILENAME:		gb_navpage.php
AUTHOR:			james bull - james@greatbridge.com
DESCRIPTION:	this file is included by *.php application files (the filename in
				the url) and is the complete navigation for greatbridge.com that
				dynamicly handles:
				- meta data
				- navigation display
				- inclusion of content templates
*** --->
<html>
<head>
<meta name="keywords" description="<?= $meta_keyword ?>">
<meta name="description" description="<?= $meta_description ?>">
<title><?= $page_title ?></title>
<style>
/*class 'leftNav'*/
a.leftNav:link{
  font-family:"arial","verdana";
  font-size: 10px;
  font-style:normal;
  color:white;
  text-decoration:none;
}
a.leftNav:visited{
  font-family:"arial","verdana";
  font-size: 10px;
  font-style:normal;
  color:white;
  text-decoration:none;
}
<? if(!empty($INCLUDE_ADDITIONAL_CSS)) {
    include($INCLUDE_ADDITIONAL_CSS);
   }
 ?>
</style>
</head>
<body bgcolor="<?= $color_2 ?>" background="<?= $image_path ?>/body_background.gif" leftmargin="0" topmargin="0" marginwidth="0" marginheight="0" vlink="<?= $color_6 ?>" alink="<?= $color_6 ?>" link="<?= $color_6 ?>">
<!-- the top table - links -->
<table background="<?= $image_path ?>/top_cellbg.gif" cellpadding="0" cellspacing="0" border="0" width="100%">
<tr background="<?= $image_path ?>/top_cellbg.gif">
<td><a href="/index.php"><img src="<?= $image_path ?>/top_logo.gif" width="221" height="32" border="0" alt="GreatBridge.com"></a></td>
<td width="100%">
	<table cellpadding="0" cellspacing="0" border="0">
	<tr>
	<td><a href="/about/about.php"><img src="<?= $image_path ?>/top1_about.gif" width="54" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/ourteam.php"><img src="<?= $image_path ?>/top1_ourteam.gif" width="59" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/presslist.php"><img src="<?= $image_path ?>/top1_news.gif" width="34" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/events.php"><img src="<?= $image_path ?>/top1_events.gif" width="41" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/careers.php"><img src="<?= $image_path ?>/top1_careers.gif" width="46" height="32" border="0"></a></td>
	</tr>
	</table>
</td>
<td><img src="<?= $image_path ?>/top_endcap.gif" width="39" height="32" border="0"></td>
</tr>
</table>
<!-- the second top layer - bottom of logo - date - special header -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td><a href="/index.php"><img src="<?= $image_path ?>/top_logo2.gif" width="221" height="45" border="0" alt="GreatBridge.com"></a></td>
<td align="right" nowrap width="100%"><font face="<?= $font_1 ?>" size="2" color="<?= $color_5 ?>"><b><? print (date ("F j, Y")); ?></b></font>&nbsp;&nbsp;&nbsp;</td>
</tr>
</table>
<!-- the middle table - left nav - content - right nav -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<!-- the left nav -->
<td valign="top">
	<table cellpadding="0" cellspacing="0" border="0" width="100%">
	<tr>
	<td colspan="2"><img src="<?= $image_path ?>/left_<?= $group_group_id ?>.gif" width="139" height="59" border="0"></td>
	</tr>
	<tr>
<!-- *** image pulled based on page group - must remain on one line to maintain spacing for
	black lined curve *** -->
	<td valign="top"><img src="<?= $image_path ?>/left_curvebottom.gif" width="22" height="20" border="0"></td>
	<td valign="top" width="100%">
	<img src="<?= $image_path ?>/shim.gif" width="117" height="5" border="0"><br>
	<!-- *** dynamicly generated navigation links *** -->
	
	<?

    function traverse_tree($t_nav_tree, $indent_code) {
        if(is_array($t_nav_tree)) {
            $child_indent = ($indent_code!=""?"<font color=\"${GLOBALS["color_2"]}\">-</font>":"");
            while(list(,$branch) = @each($t_nav_tree)) {
				$sbold = ($branch["web_page"]==$GLOBALS["web_page"]?"<b><u>":"");
				$ebold = ($branch["web_page"]==$GLOBALS["web_page"]?"</u></b>":"");
                if(strlen($branch["link_name"]) > 20) {
                    $link_name = $branch["link_name"];
                    $link_parts = explode(" ",$link_name);
                    $do = true;
                    $part_1 = "";
                    while($do) {
                        $part = array_shift($link_parts);
                        if((strlen($part_1) + strlen($part)) < 19) {
                            $part_1 .= " " . $part;
                        } else {
                            array_unshift($link_parts,$part);
                            $do = false;
                        }
                    }
                    $part_1 = trim($part_1);
                    $part_2 = implode(" ",$link_parts);
                    $branch["link_name"] = $part_1 . "<br><img src=" . $GLOBALS["image_path"] . "/shim.gif width=12 height=1 border=0>" . $part_2;
                }
			?>
	<?= $indent_code . $child_indent ?><a class="leftNav" href="<?= $branch["page_url"] ?>"><?= $sbold . $branch["link_name"] . $ebold ?></a>
	<br><img src="<?= $GLOBALS["image_path"] ?>/shim.gif" width="1" height="3"><br>
				<?
			traverse_tree($branch["children"], "<img src=" .  $GLOBALS["image_path"] . "/shim.gif width=\"5\" height=\"1\">" . $indent_code);
            }
        }
    }
	traverse_tree($nav_tree, "");
 	?>
	<?= $indent_code . $child_indent ?><a class="leftNav" href="http://www.greatbridge.org/">Developers</a>
	<br><img src="<?= $image_path ?>/shim.gif" width="1" height="3"><br>
	<!-- *** end dynamicly generated navigation links *** -->
	</td>
	</tr>
	</table>
</td>
<!-- this is the gutter -->
<td valign="top">
<img src="<?= $image_path ?>/gutter.gif" width="40" height="34" border="0"><br><img src="<?= $image_path ?>/shim.gif" width="40" height="1" border="0">
</td>
<!-- this is the content -->
<td valign="top" width="100%">
<? if($web_page != "homepage") { ?>
<br>
<font face="<?= $font_1 ?>" size="2" color="<?= $color_6 ?>"><b><?= $page_header ?></b></font><br>
<br>
<? } ?>
<!--- *** include page template *** --->
	<?
	include($template_path . "/" . $name_prefix . "_" . $web_page . ".php")
	?>
<!--- *** end page template include *** --->
</td>
<!-- gutter -->
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1" border="0"></td>
</tr>
</table>
<br><br>
<!--- footer --->
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="135" height="1"></td>
<td align="center" width="100%"><hr width="70%" noshade></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="135" height="1"></td>
<td align="center">
<a href="/about/about.php"><font face="<?= $font_1 ?>" size="2">About Us</font></a>
&nbsp;&nbsp;
<a href="/product/product.php"><font face="<?= $font_1 ?>" size="2">Products & Services</font></a>
&nbsp;&nbsp;
<a href="/about/contact.php"><font face="<?= $font_1 ?>" size="2">Contact</font></a>
</td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="135" height="1"></td>
<td align="center">
<br>
<font face="<?= $font_1 ?>" size="2" color="<?= $color_5 ?>"><b>Great Bridge, LLC . 253 Monticello Avenue . Norfolk, VA 23510 . (757) 233-5500</b></font>
</td>
</tr>
</table>
</body>
</html>
<!--- ***
END GB_NAVPAGE.PHP
*** --->

==> gbsite-2.0.0.tar.gz: gbsite/templates/gb/gb_navpage.php <==
<!--- ***
FILENAME:		gb_navpage.php
AUTHOR:			james bull - james@greatbridge.com
DESCRIPTION:	this file is included by *.php application files (the filename in
				the url) and is the complete navigation for greatbridge.com that
				dynamicly handles:
				- meta data
				- navigation display
				- inclusion of content templates
*** --->
<html>
<head>
<meta name="keywords" content="<?= $meta_keyword ?>">
<meta name="description" content="<?= $meta_description ?>">
<title><?= $page_title ?></title>
<style>
/*class 'leftNav'*/
a.leftNav:link{
  font-family:"arial","verdana";
  font-size: 10px;
  font-style:normal;
  color:white;
  text-decoration:none;
}
a.leftNav:visited{
  font-family:"arial","verdana";
  font-size: 10px;
  font-style:normal;
  color:white;
  text-decoration:none;
}
.sideBox TD {
  font-family:"arial","verdana"; font-size: 10px; font-style:normal;
}
<? if(!empty($INCLUDE_ADDITIONAL_CSS)) {
    include($INCLUDE_ADDITIONAL_CSS);
   }
 ?>
</style>
</head>
<body bgcolor="<?= $color_2 ?>" background="<?= $image_path ?>/body_background.gif" leftmargin="0" topmargin="0" marginwidth="0" marginheight="0" vlink="<?= $color_6 ?>" alink="<?= $color_6 ?>" link="<?= $color_6 ?>">
<!-- the top table - links -->
<table background="<?= $image_path ?>/top_cellbg.gif" cellpadding="0" cellspacing="0" border="0" width="100%">
<tr background="<?= $image_path ?>/top_cellbg.gif">
<td><a href="/index.php"><img src="<?= $image_path ?>/top_logo.gif" width="221" height="32" border="0" alt="GreatBridge.com"></a></td>
<td>
	<table cellpadding="0" cellspacing="0" border="0">
	<tr>
	<td><a href="/about/about.php"><img src="<?= $image_path ?>/top1_about.gif" width="54" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/ourteam.php"><img src="<?= $image_path ?>/top1_ourteam.gif" width="59" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/presslist.php"><img src="<?= $image_path ?>/top1_news.gif" width="34" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/events.php"><img src="<?= $image_path ?>/top1_events.gif" width="41" height="32" border="0"></a></td>
	<td><img src="<?= $image_path ?>/top1_pipe.gif" width="10" height="32"></td>
	<td><a href="/about/careers.php"><img src="<?= $image_path ?>/top1_careers.gif" width="46" height="32" border="0"></a></td>
	</tr>
	</table>
</td>
<td width="100%" align="right"><img src="<?= $image_path ?>/top_endcap.gif" width="39" height="32" border="0"></td>
</tr>
</table>
<!-- the second top layer - bottom of logo - date - special header -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td><a href="/index.php"><img src="<?= $image_path ?>/top_logo2.gif" width="221" height="45" border="0" alt="GreatBridge.com"></a></td>
<td align="right" nowrap width="100%"><font face="<?= $font_1 ?>" size="2" color="<?= $color_5 ?>"><b><? print (date ("F j, Y")); ?></b></font>&nbsp;&nbsp;&nbsp;</td>
</tr>
</table>
<!-- the middle table - left nav - content - right nav -->
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<!-- the left nav -->
<td valign="top">
	<table cellpadding="0" cellspacing="0" border="0" width="100%">
	<tr>
	<td colspan="2"><img src="<?= $image_path ?>/left_<?= $group_group_id ?>.gif" width="139" height="59" border="0"></td>
	</tr>
	<tr>
<!-- *** image pulled based on page group - must remain on one line to maintain spacing for
	black lined curve *** -->
	<td valign="top"><img src="<?= $image_path ?>/left_curvebottom.gif" width="22" height="20" border="0"></td>
	<td valign="top" width="100%">
	<img src="<?= $image_path ?>/shim.gif" width="117" height="5" border="0"><br>
	<!-- *** dynamicly generated navigation links *** -->
	
	<?

    function traverse_tree($t_nav_tree, $indent_code) {
        if(is_array($t_nav_tree)) {
            $child_indent = ($indent_code!=""?"<font color=\"${GLOBALS["color_2"]}\">-</font>":"");
            while(list(,$branch) = @each($t_nav_tree)) {
				$sbold = ($branch["web_page"]==$GLOBALS["web_page"]?"<b><u>":"");
				$ebold = ($branch["web_page"]==$GLOBALS["web_page"]?"</u></b>":"");
                if(strlen($branch["link_name"]) > 20) {
                    $link_name = $branch["link_name"];
                    $link_parts = explode(" ",$link_name);
                    $do = true;
                    $part_1 = "";
                    while($do) {
                        $part = array_shift($link_parts);
                        if((strlen($part_1) + strlen($part)) < 19) {
                            $part_1 .= " " . $part;
                        } else {
                            array_unshift($link_parts,$part);
                            $do = false;
                        }
                    }
                    $part_1 = trim($part_1);
                    $part_2 = implode(" ",$link_parts);
                    $branch["link_name"] = $part_1 . "<br><img src=" . $GLOBALS["image_path"] . "/shim.gif width=12 height=1 border=0>" . $part_2;
                }
			?>
	<?= $indent_code . $child_indent ?><a class="leftNav" href="<?= $branch["page_url"] ?>"><?= $sbold . $branch["link_name"] . $ebold ?></a>
	<br><img src="<?= $GLOBALS["image_path"] ?>/shim.gif" width="1" height="3"><br>
				<?
			traverse_tree($branch["children"], "<img src=" .  $GLOBALS["image_path"] . "/shim.gif width=\"5\" height=\"1\">" . $indent_code);
            }
        }
    }
	traverse_tree($nav_tree, "");
 	?>
	<?= $indent_code . $child_indent ?><a class="leftNav" href="http://www.greatbridge.org/">Developers</a>
	<br><img src="<?= $image_path ?>/shim.gif" width="1" height="13">
	<br><a class="leftNav" href="/genpage.php?register"><img src="<?= $image_path ?>/register_ani.gif" width="100" height="75" border="0"></a>
	<br><img src="<?= $image_path ?>/shim.gif" width="1" height="13"><br>
	<!-- *** end dynamicly generated navigation links *** -->
	</td>
	</tr>
	<!-- ** removed box per eric h. **
	<tr>
	<td colspan="2" align="center" class="sideBox">
		<table cellpadding="2" cellspacing="2" border="0" width="90%" bgcolor="<?= $color_1 ?>">
		<tr>
		<td bgcolor="<?= $color_2 ?>">
		Join our <a href="/genpage.php?register"><b>mailing list</b></a><br>
		-- New releases<br>
		-- Errata<br>
		-- Free swag
		<br>And more!
		</td>
		</tr>
		</table>
	</td>
	</tr> -->
	</table>
</td>
<!-- this is the gutter -->
<td valign="top">
<img src="<?= $image_path ?>/gutter.gif" width="40" height="34" border="0"><br><img src="<?= $image_path ?>/shim.gif" width="40" height="1" border="0">
</td>
<!-- this is the content -->
<td valign="top" width="100%">
<? if($web_page != "homepage") { ?>
<br>
<font face="<?= $font_1 ?>" size="2" color="<?= $color_6 ?>"><b><?= $page_header ?></b></font><br>
<br>
<? } ?>
<!--- *** include page template *** --->
	<?
	include($template_path . "/" . $name_prefix . "_" . $web_page . ".php")
	?>
<!--- *** end page template include *** --->
</td>
<!-- gutter -->
<td><img src="<?= $image_path ?>/shim.gif" width="20" height="1" border="0"></td>
</tr>
</table>
<br><br>
<!--- footer --->
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="135" height="1"></td>
<td align="center" width="100%"><hr width="70%" noshade></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="135" height="1"></td>
<td align="center">
<a href="/about/about.php"><font face="<?= $font_1 ?>" size="2">About Us</font></a>
&nbsp;&nbsp;
<a href="/product/product.php"><font face="<?= $font_1 ?>" size="2">Products & Services</font></a>
&nbsp;&nbsp;
<a href="/about/contact.php"><font face="<?= $font_1 ?>" size="2">Contact</font></a>
</td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="135" height="1"></td>
<td align="center">
<br>
<font face="<?= $font_1 ?>" size="2" color="<?= $color_5 ?>"><b>Great Bridge, LLC . 253 Monticello Avenue . Norfolk, VA 23510 . (757) 233-5500</b></font>
</td>
</tr>
</table>
</body>
</html>
<!--- ***
END GB_NAVPAGE.PHP
*** --->
